#<profile4xi profile = "10" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "assert_spawning4xi.py">
#<abstract4xi abstract = "Provides function assert_spawning4xi" />
#<refer4xi reference = "forking.py" />
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------


# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'assert_spawning4xi' ]
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
try:                 # system ones
    import os
    import sys
    import signal
except:
    pass
try:                 # threading ones       
    import threading                
    import _thread   
except:
    pass
try:                 # winapi
    import _winapi
    from _winapi import WAIT_OBJECT_0, WAIT_TIMEOUT, INFINITE
except ImportError:
    if sys.platform == 'win32':
        raise
    _winapi = None
#"
#/>

# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
import _multiprocessing
from multiprocessing import forking
#"
#/>
 
# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "
from popen4xi import Popen4Xi
from time4xi import time4xi
from print4xi import print4xi
#"
#/>

# -------------------------------------------------------------------------------------------------
#<function4xi function = "assert-spawning4xi" usage = "
#
#   queueue4xi.py
#       Queueu4Xi:
#           ___getstate__:
#               assert_spawning4xi(self)
#   heap.py:
#       assert_spawning(self)
#   queues.py:
#       from multiprocessing.forking import assert_spawning
#       assert_spawning(self)
#   sharedctypes.py:
#       assert_spawning(obj)
#   synchronize.py:
#       assert_spawning(self)
#
#">
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
# -------------------------------------------------------------------------------------------------


def assert_spawning4xi(object):
    '''
    assert_spawning4xi function: checks that the current thread is spawning a child process 
    '''
    
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------     
    
    class2print = 'assert_spawning4xi'
    method2print = 'assert_spawning4xi'
    
    message2print = "{started" + "; assert-spawning4xi-started: " + str(assert_spawning4xi)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)          

    message2print = "{passed" + "; object-passed-to-assert-spawning4xi: " + str(object) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)  
                
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------     
      
    message2print = "{trying" + "; function-trying-by-assert-spawning4xi: " + str(Popen4Xi.thread_is_spawning) + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)    
        
    try:
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
        
        if not Popen4Xi.thread_is_spawning():
   
            # -------------------------------------------------------------------------------------    
            #
            # -------------------------------------------------------------------------------------     
            message2print = "{yielded" + "; object-yielded-by-assert-spawning4xi: " + str(object)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
        
            message2print = "{warned" + "; object-warned-by-assert-spawning4xi: " + " ** objects should only be shared between processes through inheritance - object is " + str(object)  + " ** " + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            
            pass                          

        else:
            message2print = "{shared" + "; object-shared-by-assert-spawning4xi: " + str(object)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                      
              
               

    except:
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
          
                  
        message2print = "{hit" + "; Popen4Xi-thread-is-spawning-hit-by-assert-spawning4xi: " + " *** " + str(Popen4Xi.thread_is_spawning)  + " *** " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
           
        pass
    
    # ---------------------------------------------------------------------------------------------    
    #
    # ---------------------------------------------------------------------------------------------     
    message2print = "{verified" + "; object-verified-by-assert-spawning4xi: " + str(object)  + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print) 
    
    message2print = "{informed" + "; ACK4DragonXi-informed-by-assert-spawning4xi: " + str(object) + " is belonging to the current thread is spawning a child process!" + "; time: " + time4xi() + "}"
    print4xi(class2print, method2print, message2print)                          
    
    message2print = "{returning" + "; assert-spawning4xi-returning: " + time4xi() + "}" 
    print4xi(class2print, method2print, message2print)  
    
    return 
     
#</function4xi>

#</program4xi>

# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_none4xi.txt
#   sense-test-none4xi.xml
#   reason-test-none4xi.xml
#   ace-test-none4xi.xml
#"
#>


# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>

    
    

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of assert_spawning4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>
